#!/usr/bin/env bash

########################################################################################
# Choi_et_al_2023_script1.sh
# Paper: "Dietary fiber consumption is associated with the selection of key microbial species but does not affect overall microbial diversity in a Colombian cohort"
# Authors: Jinny Choi, Veronika Lewis, Claire Sie, Justin Yap
# Date: April 24, 2023
# Purpose:
	# QIIME2 analysis - generating table of unique ASVs, ASV abundances per sample, alpha/beta diversity analysis
########################################################################################

############################# QIIME2 analysis: generate table of unique ASVs #############################

PWD=pwd

# create a new directory within the working directory
mkdir $PWD/project_2


# create a new directory within project_2 directory for analysis of the colombia dataset
mkdir $PWD/project_2/colombia

# create a new directory for demultiplexing and denoising steps in the colombia directory
mkdir $PWD/project_2/colombia/demux_denoise
cd $PWD/project_2/colombia/demux_denoise

# important and demultiplex raw sequences (colombia_manifest.txt)
qiime tools import \
--type "SampleData[SequencesWithQuality]" \
--input-format SingleEndFastqManifestPhred33V2 \
--input-path /mnt/datasets/project_2/colombia_manifest.txt \
--output-path $PWD/project_2/colombia/demux_denoise/demux_seqs.qza

# visualize the demultiplexed sequences
qiime demux summarize \
--i-data $PWD/project_2/colombia/demux_denoise/demux_seqs.qza \
--o-visualization $PWD/project_2/colombia/demux_denoise/demux.qzv

# denoise with DADA2
qiime dada2 denoise-single \
--i-demultiplexed-seqs $PWD/project_2/colombia/demux_denoise/demux_seqs.qza \
--p-trim-left 0 \
--p-trunc-len 250 \
--o-representative-sequences $PWD/project_2/colombia/demux_denoise/rep-seqs.qza \
--o-table $PWD/project_2/colombia/demux_denoise/table.qza \
--o-denoising-stats $PWD/project_2/colombia/demux_denoise/stats.qza

# create a feature table
qiime feature-table summarize \
--i-table $PWD/project_2/colombia/demux_denoise/table.qza \
--o-visualization $PWD/project_2/colombia/demux_denoise/table.qza \
--m-sample-metadata-file /mnt/datasets/project_2/colombia_metadata.txt

# visualize representative sequences
qiime feature-table tabulate-seqs \
--i-data $PWD/project_2/colombia/demux_denoise/rep-seqs.qza \
--o-visualization $PWD/project_2/colombia/demux_denoise/rep-seqs.qzv


############################# QIIME2 analysis: train classifier from SILVA reference database and use to assign taxonomy #############################

# make a new directory within the colombia directory
mkdir $PWD/project_2/colombia/ref_files

# extract amplicon of interest from the reference database (information obtained from de la Cuesta-Zuluaga et al.'s paper)
qiime feature-classifier extract-reads \
  --i-sequences /mnt/datasets/silva_ref_files/silva-138-99-seqs.qza \
  --p-f-primer GTGCCAGCMGCCGCGGTAA \
  --p-r-primer GGACTACHVGGGTWTCTAAT \
  --p-trunc-len 250 \
  --o-reads $PWD/project_2/colombia/ref_files/ref-seqs-trimmed.qza

# train classifier with the trimmed ref-seq file
qiime feature-classifier fit-classifier-naive-bayes \
  --i-reference-reads $PWD/project_2/colombia/ref_files/ref-seqs-trimmed.qza \
  --i-reference-taxonomy /mnt/datasets/silva_ref_files/silva-138-99-tax.qza \
  --o-classifier $PWD/project_2/colombia/ref_files/classifier.qza


# make a new directory within the colombia directory for taxonomy files
mkdir $PWD/project_2/colombia/taxonomy_phylogeny

# use the newly trained classifier to assign taxonomy to our reads (rep-seqs.qza file)
qiime feature-classifier classify-sklearn \
  --i-classifier $PWD/project_2/colombia/ref_files/classifier.qza \
  --i-reads $PWD/project_2/colombia/demux_denoise/rep-seqs.qza \
  --o-classification $PWD/project_2/colombia/taxonomy_phylogeny/taxonomy.qza

# visualize the taxonomy file
qiime metadata tabulate \
  --m-input-file $PWD/project_2/colombia/taxonomy_phylogeny/taxonomy.qza \
  --o-visualization $PWD/project_2/colombia/taxonomy_phylogeny/taxonomy.qzv

# taxonomy-based filtering of the data (exclude mitochondrial and chloroplast sequences)  
qiime taxa filter-table \
  --i-table $PWD/project_2/colombia/demux_denoise/table.qza \
  --i-taxonomy $PWD/project_2/colombia/taxonomy_phylogeny/taxonomy.qza \
  --p-exclude mitochondria,chloroplast \
  --o-filtered-table $PWD/project_2/colombia/demux_denoise/table-no-mitochondria-no-chloroplast.qza

# visualize filtered table.qza file 
qiime feature-table summarize \
--i-table $PWD/project_2/colombia/demux_denoise/table-no-mitochondria-no-chloroplast.qza \
--o-visualization $PWD/project_2/colombia/demux_denoise/table-no-mitochondria-no-chloroplast.qzv \
--m-sample-metadata-file /mnt/datasets/project_2/colombia_metadata.txt

# generate rooted and unrooted trees using fasttree
qiime phylogeny align-to-tree-mafft-fasttree \
  --i-sequences $PWD/project_2/colombia/demux_denoise/rep-seqs.qza \
  --o-alignment $PWD/project_2/colombia/taxonomy_phylogeny/aligned-rep-seqs.qza \
  --o-masked-alignment $PWD/project_2/colombia/taxonomy_phylogeny/masked-aligned-rep-seqs.qza \
  --o-tree $PWD/project_2/colombia/taxonomy_phylogeny/unrooted-tree.qza \
  --o-rooted-tree $PWD/project_2/colombia/taxonomy_phylogeny/rooted-tree.qza 

# generate an alpha-rarefaction curve using the rooted tree.qza file
qiime diversity alpha-rarefaction \
  --i-table $PWD/project_2/colombia/demux_denoise/table.qza \
  --i-phylogeny $PWD/project_2/colombia/taxonomy_phylogeny/rooted-tree.qza  \
  --p-max-depth 105000 \
  --m-metadata-file /mnt/datasets/project_2/colombia_metadata.txt \
  --o-visualization $PWD/project_2/colombia/taxonomy_phylogeny/alpha-rarefaction.qzv


############################# convert QIIME2 output files for R analysis #############################

# create a directory for exporting QIIME2 output files
mkdir $PWD/project_2/colombia/export

# export the table.qza file for analysis in R
qiime tools export \
        --input-path $PWD/project_2/colombia/demux_denoise/table.qza \
        --output-path $PWD/project_2/colombia/export/table_export

# convert the feature table from biom format to txt so that it is readable in R
biom convert -i $PWD/project_2/colombia/export/table_export/feature-table.biom --to-tsv -o $PWD/project_2/colombia/export/table_export/feature-table.txt

# export the taxonomy.qza file for analysis in R
qiime tools export \
        --input-path $PWD/project_2/colombia/taxonomy_phylogeny/taxonomy.qza \
        --output-path $PWD/project_2/colombia/export/taxonomy_export

# export the rooted tree for analysis in R
qiime tools export \
        --input-path $PWD/project_2/colombia/taxonomy_phylogeny/rooted-tree.qza \
        --output-path $PWD/project_2/colombia/export/rooted-tree_export

# transfer the entire export directory into the local directory along with the metadata.txt file

