#!/usr/bin/env Rscript

#########################################################################################################
# Choi_et_al_2023_script2.R
# Paper: "Dietary fiber consumption is associated with the selection of key microbial species but does not affect overall microbial diversity in a Colombian cohort"
# Authors: Jinny Choi, Veronika Lewis, Claire Sie, Justin Yap
# Date: April 24, 2023
# Purpose: 
    # R analysis - stratification of samples based on fiber intake
    # R analysis - alpha/beta diversity analysis
#########################################################################################################

# load packages
library(ggplot2)

############################# stratification of samples from the whole cohort based on fiber intake #############################

# load colombia metadata file
metafp <- "./colombia_metadata.txt"
meta <- read_delim(metafp, delim="\t")
colnames(meta)[1] <- "sampleid"

view(meta)

# add a new column (fiber_over_caloric) to the metadata file which divides the fiber intake (g) over the caloric intake
meta$fiber_over_caloric <- meta$fiber/meta$Calorie_intake

# write a function to assign the value "adequate" if the fiber_over_caloric value is greater than or equal to 0.014 g/cal
# this function should assign the value "inadequate" if the fiber_over_caloric is less than 0.014 g/cal
# this value was taken from a published report from the Government of Colombia
# these values should be assigned in a new column titled fiber_adequate
assign_fiber_adequacy <- function(data) {
  data$fiber_adequate <- ifelse(data$fiber_over_caloric >= 0.014, "adequate", "inadequate")
  return(data)
}

# use the function on the colombia metadata to assign "adequate" and "inadequate" fiber intake to samples
meta <- assign_fiber_adequacy(meta)

# determine how many samples have adequate fiber intake
fiber_adequate_samples <- meta$fiber_over_caloric >= 0.014
adequate_data <- meta[fiber_adequate_samples, ]
count(adequate_data)
# there are 22 samples deemed to have adequate fiber intake

# determine how many samples have inadequate fiber intake
fiber_inadequate_samples <- meta$fiber_over_caloric < 0.014
inadequate_data <- meta[fiber_inadequate_samples, ]
count(inadequate_data)
# there are 419 samples deemed to have inadequate fiber intake

# since the sample sizes differ so significantly, we chose to stratify the samples with inadequate fiber intake
# further by dividing the inadequate fiber intake group into three groups of approximately equal numbers of samples.

# divide the samples in the inadequate fiber intake group into three quantiles based on fiber_over_caloric
low_fiber_categories <- cut(inadequate_data$fiber_over_caloric, 
                            breaks = quantile(inadequate_data$fiber_over_caloric,
                                              probs = c(0, 1/3, 2/3, 1)))

# generate a table to determine the fiber_over_caloric cutoff values for each quantile 
table(low_fiber_categories)
# the inadequate samples are divided into three groups with 139 (high), 139 (mid), and 140 (low) in each group
# max and min values for each group: 
# low: (0.00332, 0.00799]
# mid: (0.00799, 0.00986]
# high: (0.00986, 0.0139]

# assign cutoff values for stratifying the inadequate fiber samples
cutoffs <- c(0.00799, 0.00986, 0.0139)

# assign categories corresponding to the cutoff values determined above
categories <- c("low_inadequate", "mid_inadequate", "high_inadequate", "adequate")

# write a function to assign fiber categories based on the cutoffs defined
# the function reads a data frame and creates a new column (fiber_category)
# it then assigns samples specific values defined in categories variable based off
# of specific values in the defined cutoffs variable
assign_fiber_category <- function(data, fiber, cutoffs, categories) {  
  data$fiber_category <- ifelse(data[[fiber]] < cutoffs[1], categories[1],                                
                                ifelse(data[[fiber]] >= cutoffs[1] & data[[fiber]] < cutoffs[2],                                        categories[2],                                       
                                       ifelse(data[[fiber]] >= cutoffs[2] & data[[fiber]] < cutoffs[3],                                               categories[3],                                              
                                              ifelse(data[[fiber]] >= cutoffs[3],
                                                     categories[4], NA)))) 
  return(data)
}

# assign the samples in the meta dataframe with fiber categories based off defined cutoff values from above
meta_fiber_groups <- assign_fiber_category(meta, "fiber_over_caloric", cutoffs, categories)

# visualize the fiber category assignments using ggplot (Fig 1A)
whole_cohort_fiber_subset_hist <- ggplot(data = meta_fiber_groups, 
                                         aes(x = fiber_over_caloric, fill = fiber_category)) +
  labs(x = "Fiber/Caloric (g/cal)", y = "Number of samples") +
  geom_histogram(bins = 30) +
  theme(axis.title.y = element_text(face = "bold"),
        axis.title.x = element_text(face = "bold")) +
  scale_fill_manual(name = "Fiber Intake",
                    limits = c("adequate", "high_inadequate", "mid_inadequate", "low_inadequate"),
                    values = c("#67a9cf", "#fddbc7", "#ef8a62", "#b2182b"),
                    labels = c("Adequate", "High Inadequate", "Mid Inadequate", "Low Inadequate"))

ggsave("whole_fiber_subset_histogram.png", plot = whole_cohort_fiber_subset_hist, height = 4, width = 5)


############################# stratification of samples from a subsetted cohort based on fiber intake #############################

# decided to look at a subset of the cohort in order to account for differences/confounding variables such as sex and age

# look at the breakdown of samples for each sex in the cohort
# check number of female samples in the cohort
female_rows <- meta$sex == "female"
female_only <- meta[female_rows, ]
count(female_only)
# there are 229 females within the dataset

# check number of males
male_rows <- meta$sex == "male"
male_only <- meta[male_rows, ]
count(male_only)
# there are 212 males within the dataset

# look at the different age ranges present within the dataset
meta$age_range <- factor(meta$age_range)
unique(meta$age_range)
# we have two age groups: 18-40 year olds and 41-62 year olds

# since there are more female samples, let's look at the breakdown of females for each age range
females_18_40 <- female_only$age_range == "18_40"
females_young_only <- female_only[females_18_40, ]
count(females_young_only)
# there are 109 females between age 18-40

females_41_62 <- female_only$age_range == "41_62"
females_old_only <- female_only[females_41_62, ]
count(females_old_only)
# there are 120 females between age 41-62 

# so we will be analyzing a subset of the whole cohort (specifically the females between age 41-62) since we have the most samples belonging to this population

# subset the colombian metadata file to only include the older females aged 41-62
females_older_meta <- female_only[females_41_62, ]

# determine how many samples in the older female cohort have adequate fiber intake
count(females_older_meta, females_older_meta$fiber_over_caloric >= 0.014)
# there are 11 samples deemed to have adequate fiber intake in this older female cohort
# there are 109 samples deemed to have inadequate fiber intake in this older female cohort

# since we still see a large difference in sample sizes between adequate and inadequate groups, we need to determine
# the appropriate cutoffs to use to stratify the inadequate fiber intake samples into high-inadequate, mid-inadequate, and low-inadequate

# determine how many older female samples have inadequate fiber intake
fiber_inadequate_OF_samples <- females_older_meta$fiber_over_caloric < 0.014
inadequate_OF_data <- females_older_meta[fiber_inadequate_OF_samples, ]

# divide the older female inadequate fiber intake group into three quantiles based on fiber intake
OF_low_fiber_categories <- cut(inadequate_OF_data$fiber_over_caloric, 
                               breaks = quantile(inadequate_OF_data$fiber_over_caloric,
                                                 probs = c(0, 1/3, 2/3, 1)))
table(OF_low_fiber_categories)
# generates 3 groups with 36 (high), 36 (mid), and 36 (low) in each group# max and min values for each group: 
# low: (0.00472, 0.00844]
# mid: (0.00844, 0.0102]
# high: (0.0102, 0.0138]

OF_cutoffs <- c(0.00844, 0.0102, 0.0138)
OF_categories <- c("low_inadequate", "mid_inadequate", "high_inadequate", "adequate")

# using the function written previously, assign fiber categories based off cutoffs defined above for older females
meta_OF_fiber_groups <- assign_fiber_category(females_older_meta, "fiber_over_caloric", OF_cutoffs, OF_categories)

# visualize the fiber category assignments for this subsetted cohort using ggplot (Fig 1B)
OF_cohort_fiber_subset_hist <- ggplot(data = meta_OF_fiber_groups, aes(x = fiber_over_caloric, fill = fiber_category)) +
  labs(x = "Fiber/Caloric (g/cal)", y = "Number of samples") +
  geom_histogram(bins = 30) +
  theme(axis.title.y = element_text(face = "bold"),
        axis.title.x = element_text(face = "bold")) +
  scale_fill_manual(name = "Fiber Intake",
                    limits = c("adequate", "high_inadequate", "mid_inadequate", "low_inadequate"),
                    values = c("#67a9cf", "#fddbc7", "#ef8a62", "#b2182b"),
                    labels = c("Adequate", "High Inadequate", "Mid Inadequate", "Low Inadequate"))

ggsave("OF_fiber_subset_histogram.png", plot = OF_cohort_fiber_subset_hist, height = 4, width = 5)


############################# generation of phyloseq file from QIIME2 output files and stratified metadata #############################

# load required packages
library(phyloseq)
library(vegan) # for function rarecurve

#load and format feature table exported from QIIME2 #
otufp <- "feature-table.txt"
otu <- read_delim(file = otufp, delim="\t", skip=1)

# save everything except first column (OTU ID) into a matrix
otu_mat <- as.matrix(otu[,-1])
# make first column (#OTU ID) the rownames of the new matrix
rownames(otu_mat) <- otu$`#OTU ID`
# use the "otu_table" function to make an OTU table
OTU <- otu_table(otu_mat, taxa_are_rows = TRUE) 
class(OTU) # check that the OTU table is the correct class

# load and format taxonomy file output from QIIME2 #
taxfp <- "taxonomy.tsv"
tax <- read_delim(taxfp, delim="\t")

# convert taxon strings to a table with separate taxa rank columns
tax_mat <- tax %>%
  separate(col=Taxon, sep="; "
           , into = c("Domain","Phylum","Class","Order","Family","Genus","Species")) %>%
  as.matrix() # Saving as a matrix
# save everything except feature IDs 
tax_mat <- tax_mat[,-1]
# make sampleids the rownames
rownames(tax_mat) <- tax$`Feature ID`
# Make taxa table
TAX <- tax_table(tax_mat)
class(TAX) # check that the taxonomy file is the correct class

# read rooted tree exported from QIIME2 #
phylotreefp <- "tree.nwk"
phylotree <- read_tree(phylotreefp)


# format the sample metadata for the whole cohort (stratified)
# save everything except sampleid as new data frame
whole_samp_df <- as.data.frame(meta_fiber_groups[,-1])
# Make sampleids the rownames
rownames(whole_samp_df)<- meta_fiber_groups$sampleid
# Make phyloseq sample data with sample_data() function
whole_SAMP <- sample_data(whole_samp_df)
class(whole_SAMP) # check that the metadata file is the correct class

# format the sample metadata for the older female subsetted cohort (stratified)
# save everything except sampleid as new data frame
OF_samp_df <- as.data.frame(meta_OF_fiber_groups[,-1])
# Make sampleids the rownames
rownames(OF_samp_df)<- meta_OF_fiber_groups$sampleid
# Make phyloseq sample data with sample_data() function
OF_SAMP <- sample_data(OF_samp_df)
class(OF_SAMP) # check that the metadata file is the correct class

#### create phyloseq object for whole cohort data ####
colombia_whole <- phyloseq(OTU, whole_SAMP, TAX, phylotree)

# filter the whole cohort phyloseq file
# filter out chloroplast and mitochondrial sequences
whole_colombia_filt <- subset_taxa(colombia_whole,  Domain == "d__Bacteria" & Class!="c__Chloroplast" & Family !="f__Mitochondria")

# filter out low abundance taxa
whole_colombia_filt_nolow <- filter_taxa(whole_colombia_filt, function(x) sum(x)>5, prune = TRUE)

# filter out samples with very few reads
whole_colombia_filt_nolow_samps <- prune_samples(sample_sums(whole_colombia_filt_nolow)>100, whole_colombia_filt_nolow)

# filter out samples that don't have assigned fiber categories
whole_colombia_final <- subset_samples(whole_colombia_filt_nolow_samps, !is.na(fiber_category))

# save the filtered phyloseq file for reproducibility
save(whole_colombia_final, file = "whole_colombia_final.RData")

# plot an alpha rarefaction curve
rarecurve(t(as.data.frame(otu_table(whole_colombia_final))), cex = 0.1)

# determined optimal sampling depth for the whole cohort to be 22513 
# this was determined by looking at a combination of the alpha rarefaction curve generated here in R and with the table.qzv file generated with QIIME2
# retains 19 adequate fiber samples, 354 inadequate fiber samples
# retains 54.49% of features and 373 samples 
whole_colombia_rare_22513_depth <- rarefy_even_depth(whole_colombia_final, rngseed = 1, sample.size = 22513)

save(whole_colombia_rare_22513_depth, file = "whole_colombia_rare_22513_depth.RData")


#### create phyloseq object for older female subset of data #### 
colombia_OF <- phyloseq(OTU, OF_SAMP, TAX, phylotree)

# filter the older female subset phyloseq file
# filter out chloroplast and mitochondrial sequences
colombia_OF_filt <- subset_taxa(colombia_OF,  Domain == "d__Bacteria" & Class!="c__Chloroplast" & Family !="f__Mitochondria")

# filter out low abundance taxa
colombia_OF_filt_nolow <- filter_taxa(colombia_OF_filt, function(x) sum(x)>5, prune = TRUE)

# filter out samples with very few reads
colombia_OF_filt_nolow_samps <- prune_samples(sample_sums(colombia_OF_filt_nolow)>100, colombia_OF_filt_nolow)

# filter out samples that don't have assigned fiber categories
colombia_OF_final <- subset_samples(colombia_OF_filt_nolow_samps, !is.na(fiber_category))


# save the filtered phyloseq file for reproducibility
save(colombia_OF_final, file = "colombia_OF_final.RData")

# plot an alpha rarefaction curve
rarecurve(t(as.data.frame(otu_table(colombia_OF_final))), cex = 0.1)

# determined optimal sampling depth for the whole cohort to be 9438 
# this was determined by looking at a combination of the alpha rarefaction curve generated here in R and with the table.qzv file generated with QIIME2
# retains 11 adequate fiber samples, 115 inadequate fiber samples
# retains 26.55% of features and 117 (97.50%) samples 
colombia_OF_rare_9438_depth <- rarefy_even_depth(colombia_OF_final, rngseed = 1, sample.size = 9438)

save(colombia_OF_rare_9438_depth, file = "colombia_OF_rare_9438_depth.RData")


############################# alpha diversity analyses on whole cohort and older female cohort #############################

#### plot the alpha diversity metrics for the whole cohort samples (Fig 1C)
whole_fiber_groups_alphadiv <- plot_richness(whole_colombia_rare_22513_depth, 
                                          x= "fiber_category") +
  geom_boxplot(aes(fill=fiber_category)) + theme_bw() +  
  scale_x_discrete(name = "Fiber Intake",                   
                   limits = c("low_inadequate", "mid_inadequate", "high_inadequate", "adequate"),                   
                   labels = c("Low Inadequate", "Mid Inadequate", "High Inadequate", "Adequate")) +  
  scale_fill_manual(name = "Fiber Intake",
                    limits = c("low_inadequate", "mid_inadequate", "high_inadequate", "adequate"),
                    values = c("#b2182b", "#ef8a62", "#fddbc7", "#67a9cf"),                    
                    labels = c("Low Inadequate", "Mid Inadequate", "High Inadequate", "Adequate")) +  
  theme(axis.title.y = element_text(face = "bold"),        
        axis.title.x = element_text(face = "bold"),        
        axis.text.x = element_text(angle = 45, hjust = 1))    

ggsave("whole_fiber_groups_alphadiv.png", plot = whole_fiber_groups_alphadiv, width = 10, height = 4)

# calculate alpha diversity metrics for whole cohort 
whole_alphadiv <- estimate_richness(whole_colombia_rare_22513_depth)

# isolate the sample data from the rarefied whole cohort phyloseq file
whole_sampdat <- sample_data(whole_colombia_rare_22513_depth)

# combine the calculated alpha diversity indices with sample data
whole_sampdat_wdiv <- data.frame(whole_sampdat, whole_alphadiv)


# perform statistical analyses on alpha diversity metrics

# perform ANOVA on observed features diversity metric
whole_obs_anova <- aov(Observed ~ fiber_category, whole_sampdat_wdiv)
summary(whole_obs_anova)
# Pr(<F) = 0.658, ns

# perform ANOVA on Chao1 diversity metric
whole_chao1_anova <- aov(Chao1 ~ fiber_category, whole_sampdat_wdiv)
summary(whole_chao1_anova)
# Pr(<F) = 0.705, ns

# perform ANOVA on ACE diversity metric
whole_ACE_anova <- aov(ACE ~ fiber_category, whole_sampdat_wdiv)
summary(whole_ACE_anova)
# Pr(<F) = 0.686, ns

# perform ANOVA on Shannon diversity metric
whole_Shannon_anova <- aov(Shannon ~ fiber_category, whole_sampdat_wdiv)
summary(whole_Shannon_anova)
# Pr(<F) = 0.37, ns

# perform ANOVA on Simpson diversity metric
whole_Simpson_anova <- aov(Simpson ~ fiber_category, whole_sampdat_wdiv)
summary(whole_Simpson_anova)
# Pr(<F) = 0.467, ns

# perform ANOVA on InvSimpson diversity metric
whole_InvSimpson_anova <- aov(InvSimpson ~ fiber_category, whole_sampdat_wdiv)
summary(whole_InvSimpson_anova)
# Pr(<F) = 0.376, ns

# perform ANOVA on Fisher diversity metric
whole_Fisher_anova <- aov(Fisher ~ fiber_category, whole_sampdat_wdiv)
summary(whole_Fisher_anova)
# Pr(<F) = 0.689, ns


#### plot the alpha diversity metrics for the older female subsetted cohort (Fig 1D) 
OF_fiber_groups_alphadiv <- plot_richness(colombia_OF_rare_9438_depth, 
                                          x= "fiber_category") +
  geom_boxplot(aes(fill=fiber_category)) + theme_bw() +  
  scale_x_discrete(name = "Fiber Intake",                   
                   limits = c("low_inadequate", "mid_inadequate", "high_inadequate", "adequate"),                   
                   labels = c("Low Inadequate", "Mid Inadequate", "High Inadequate", "Adequate")) +  
  scale_fill_manual(name = "Fiber Intake",
                    limits = c("low_inadequate", "mid_inadequate", "high_inadequate", "adequate"),
                    values = c("#b2182b", "#ef8a62", "#fddbc7", "#67a9cf"),                    
                    labels = c("Low Inadequate", "Mid Inadequate", "High Inadequate", "Adequate")) +  
  theme(axis.title.y = element_text(face = "bold"),        
        axis.title.x = element_text(face = "bold"),        
        axis.text.x = element_text(angle = 45, hjust = 1))    

ggsave("OF_fiber_groups_alphadiv.png", plot = OF_fiber_groups_alphadiv, width = 10, height = 4)

# calculate alpha diversity metrics for older female cohort
OF_alphadiv <- estimate_richness(colombia_OF_rare_9438_depth)

# isolate the sample data from the rarefied whole cohort phyloseq file
OF_sampdat <- sample_data(colombia_OF_rare_9438_depth)

# combine the calculated alpha diversity indices with sample data
OF_sampdat_wdiv <- data.frame(OF_sampdat, OF_alphadiv)

# perform statistical analyses on alpha diversity metrics for older female cohort

# perform ANOVA on observed features diversity metric
OF_obs_anova <- aov(Observed ~ fiber_category, OF_sampdat_wdiv)
summary(OF_obs_anova)
# Pr(<F) = 0.6, ns

# perform ANOVA on Chao1 diversity metric
OF_chao1_anova <- aov(Chao1 ~ fiber_category, OF_sampdat_wdiv)
summary(OF_chao1_anova)
# Pr(<F) = 0.709, ns

# perform ANOVA on ACE diversity metric
OF_ACE_anova <- aov(ACE ~ fiber_category, OF_sampdat_wdiv)
summary(OF_ACE_anova)
# Pr(<F) = 0.73, ns

# perform ANOVA on Shannon diversity metric
OF_Shannon_anova <- aov(Shannon ~ fiber_category, OF_sampdat_wdiv)
summary(OF_Shannon_anova)
# Pr(<F) = 0.149, ns

# perform ANOVA on Simpson diversity metric
OF_Simpson_anova <- aov(Simpson ~ fiber_category, OF_sampdat_wdiv)
summary(OF_Simpson_anova)
# Pr(<F) = 0.104, ns

# perform ANOVA on InvSimpson diversity metric
OF_InvSimpson_anova <- aov(InvSimpson ~ fiber_category, OF_sampdat_wdiv)
summary(OF_InvSimpson_anova)
# Pr(<F) = 0.394, ns

# perform ANOVA on Fisher diversity metric
OF_Fisher_anova <- aov(Fisher ~ fiber_category, OF_sampdat_wdiv)
summary(OF_Fisher_anova)
# Pr(<F) = 0.66, ns

############################# beta diversity analyses on whole cohort and older female cohort #############################
library(vegan) # for adonis2 (PERMANOVA) analysis

#### plot the beta diversity metrics for the whole cohort (weighted unifrac PCoA used for Fig S1A) 

# plot Bray-Curtis PCoA for whole cohort
whole_bc_dm <- distance(whole_colombia_rare_22513_depth, method = "bray")
whole_pcoa_bc <- ordinate(whole_colombia_rare_22513_depth, method = "PCoA", distance = whole_bc_dm)

whole_bc_pcoa <- plot_ordination(whole_colombia_rare_22513_depth, whole_pcoa_bc, color = "fiber_category") +
  labs(pch="Fiber intake", col = "fiber_category") + 
  scale_color_manual(name = "Fiber Intake",
                     values = c("#b2182c", "#ef8a62", "#fddbc7", "#67a9cf"),                    
                     labels = c("Low Inadequate", "Mid Inadequate", "High Inadequate", "Adequate")) + 
  theme_bw()

ggsave("whole_bc_pcoa.png", whole_bc_pcoa, height = 4, width = 5)


# plot Jaccard PCoA for whole cohort
whole_jc_dm <- distance(whole_colombia_rare_22513_depth, method = "jaccard")
whole_pcoa_jc <- ordinate(whole_colombia_rare_22513_depth, method = "PCoA", distance = whole_jc_dm)

whole_jc_pcoa <- plot_ordination(whole_colombia_rare_22513_depth, whole_pcoa_jc, color = "fiber_category") +
  labs(pch="Fiber intake", col = "fiber_category") + 
  scale_color_manual(name = "Fiber Intake",
                     values = c("#b2182c", "#ef8a62", "#fddbc7", "#67a9cf"),                    
                     labels = c("Low Inadequate", "Mid Inadequate", "High Inadequate", "Adequate")) + 
  theme_bw()

ggsave("whole_jc_pcoa.png", whole_jc_pcoa, height = 4, width = 5)


# plot UniFrac PCoA for whole cohort
whole_uf_dm <- distance(whole_colombia_rare_22513_depth, method = "unifrac")
whole_pcoa_uf <- ordinate(whole_colombia_rare_22513_depth, method = "PCoA", distance = whole_uf_dm)

whole_uf_pcoa <- plot_ordination(whole_colombia_rare_22513_depth, whole_pcoa_uf, color = "fiber_category") +
  labs(pch="Fiber intake", col = "fiber_category") + 
  scale_color_manual(name = "Fiber Intake",
                     values = c("#b2182c", "#ef8a62", "#fddbc7", "#67a9cf"),                    
                     labels = c("Low Inadequate", "Mid Inadequate", "High Inadequate", "Adequate")) + 
  theme_bw()

ggsave("whole_uf_pcoa.png", whole_uf_pcoa, height = 4, width = 5)


# plot weighted UniFrac PCoA for whole cohort (Fig S1A)
whole_wuf_dm <- distance(whole_colombia_rare_22513_depth, method = "wunifrac")
whole_pcoa_wuf <- ordinate(whole_colombia_rare_22513_depth, method = "PCoA", distance = whole_wuf_dm)

whole_wuf_pcoa <- plot_ordination(whole_colombia_rare_22513_depth, whole_pcoa_wuf, color = "fiber_category") +
  labs(pch="Fiber intake", col = "fiber_category") + 
  scale_color_manual(name = "Fiber Intake",
                     values = c("#b2182c", "#ef8a62", "#fddbc7", "#67a9cf"),                    
                     labels = c("Low Inadequate", "Mid Inadequate", "High Inadequate", "Adequate")) + 
  theme_bw()

ggsave("whole_wuf_pcoa.png", whole_wuf_pcoa, height = 4, width = 5)


# perform statistical analyses on beta diversity metrics for whole cohort

# PERMANOVA on Bray-Curtis distances for whole cohort
set.seed(12345)
adonis2(whole_bc_dm ~ fiber_category, data = whole_sampdat_wdiv)
# Pr(<F) = 0.631, ns

# PERMANOVA on Jaccard distances for whole cohort
set.seed(12345)
adonis2(whole_jc_dm ~ fiber_category, data = whole_sampdat_wdiv)
# Pr(<F) = 0.633, ns

# PERMANOVA on UniFrac distances for whole cohort
set.seed(12345)
adonis2(whole_uf_dm ~ fiber_category, data = whole_sampdat_wdiv)
# Pr(<F) = 0.494, ns

# PERMANOVA on Weighted UniFrac distances for whole cohort
set.seed(12345)
adonis2(whole_wuf_dm ~ fiber_category, data = whole_sampdat_wdiv)
# Pr(<F) = 0.83, ns



#### plot the beta diversity metrics for the older female cohort (weighted unifrac PCoA used for Fig S1B) 

# plot Bray-Curtis PCoA for older female cohort
OF_bc_dm <- distance(colombia_OF_rare_9438_depth, method = "bray")
OF_pcoa_bc <- ordinate(colombia_OF_rare_9438_depth, method = "PCoA", distance = OF_bc_dm)

OF_bc_pcoa <- plot_ordination(colombia_OF_rare_9438_depth, OF_pcoa_bc, color = "fiber_category") +
  labs(pch="Fiber intake", col = "fiber_category") + 
  scale_color_manual(name = "Fiber Intake",
                     values = c("#b2182c", "#ef8a62", "#fddbc7", "#67a9cf"),                    
                     labels = c("Low Inadequate", "Mid Inadequate", "High Inadequate", "Adequate")) + 
  theme_bw()

ggsave("OF_bc_pcoa.png", OF_bc_pcoa, height = 4, width = 5)


# plot Jaccard PCoA for older female cohort
OF_jc_dm <- distance(colombia_OF_rare_9438_depth, method = "jaccard")
OF_pcoa_jc <- ordinate(colombia_OF_rare_9438_depth, method = "PCoA", distance = OF_jc_dm)

OF_jc_pcoa <- plot_ordination(colombia_OF_rare_9438_depth, OF_pcoa_jc, color = "fiber_category") +
  labs(pch="Fiber intake", col = "fiber_category") + 
  scale_color_manual(name = "Fiber Intake",
                     values = c("#b2182c", "#ef8a62", "#fddbc7", "#67a9cf"),                    
                     labels = c("Low Inadequate", "Mid Inadequate", "High Inadequate", "Adequate")) + 
  theme_bw()

ggsave("OF_jc_pcoa.png", OF_jc_pcoa, height = 4, width = 5)


# plot UniFrac PCoA for older female cohort
OF_uf_dm <- distance(colombia_OF_rare_9438_depth, method = "unifrac")
OF_pcoa_uf <- ordinate(colombia_OF_rare_9438_depth, method = "PCoA", distance = OF_uf_dm)

OF_uf_pcoa <- plot_ordination(colombia_OF_rare_9438_depth, OF_pcoa_uf, color = "fiber_category") +
  labs(pch="Fiber intake", col = "fiber_category") + 
  scale_color_manual(name = "Fiber Intake",
                     values = c("#b2182c", "#ef8a62", "#fddbc7", "#67a9cf"),                    
                     labels = c("Low Inadequate", "Mid Inadequate", "High Inadequate", "Adequate")) + 
  theme_bw()

ggsave("OF_uf_pcoa.png", OF_uf_pcoa, height = 4, width = 5)


# plot weighted UniFrac PCoA for older female cohort (Fig S1B)
OF_wuf_dm <- distance(colombia_OF_rare_9438_depth, method = "wunifrac")
OF_pcoa_wuf <- ordinate(colombia_OF_rare_9438_depth, method = "PCoA", distance = OF_wuf_dm)

OF_wuf_pcoa <- plot_ordination(colombia_OF_rare_9438_depth, OF_pcoa_wuf, color = "fiber_category") +
  labs(pch="Fiber intake", col = "fiber_category") + 
  scale_color_manual(name = "Fiber Intake",
                     values = c("#b2182c", "#ef8a62", "#fddbc7", "#67a9cf"),                    
                     labels = c("Low Inadequate", "Mid Inadequate", "High Inadequate", "Adequate")) + 
  theme_bw()

ggsave("OF_wuf_pcoa.png", OF_wuf_pcoa, height = 4, width = 5)


# perform statistical analyses on beta diversity metrics for older female cohort

# PERMANOVA on Bray-Curtis distances for older female cohort
set.seed(12345)
adonis2(OF_bc_dm ~ fiber_category, data = OF_sampdat_wdiv)
# Pr(<F) = 0.858, ns

# PERMANOVA on Jaccard distances for older female cohort
set.seed(12345)
adonis2(OF_jc_dm ~ fiber_category, data = OF_sampdat_wdiv)
# Pr(<F) = 0.885, ns

# PERMANOVA on UniFrac distances for older female cohort
set.seed(12345)
adonis2(OF_uf_dm ~ fiber_category, data = OF_sampdat_wdiv)
# Pr(<F) = 0.753, ns

# PERMANOVA on Weighted UniFrac distances for older female cohort
set.seed(12345)
adonis2(OF_wuf_dm ~ fiber_category, data = OF_sampdat_wdiv)
# Pr(<F) = 0.853, ns

