#!/usr/bin/env Rscript

#########################################################################################################
# Choi_et_al_2023_script3.R
# Paper: "Dietary fiber consumption is associated with the selection of key microbial species but does not affect overall microbial diversity in a Colombian cohort"
# Authors: Jinny Choi, Veronika Lewis, Claire Sie, Justin Yap
# Date: April 24, 2023
# Purpose: 
    # R analysis - Differential abundance analysis using DESeq2
    # R analysis - Core microbiome analysis 
    # R analysis - Indicator species analysis using indicspecies
#########################################################################################################

# load packages
library(DESeq2)
library(ggplot2)
library(ggrepel)
library(phyloseq)
library(dplyr)

############################# Differential abundance analysis using DESeq2 #############################

# load phyloseq files for whole cohort and older female cohort

load("whole_colombia_final.RData")

load("colombia_OF_final.RData")

# DESeq analysis on whole cohort 

# first, filter out values of 0 fiber groups for DESeq 
# since we get a zeros error with unprocessed data, we need to add a '1' count to all reads

whole_colombia_plus1 <- transform_sample_counts(whole_colombia_final, function(x) x+1)

# convert the phyloseq file to a file format readable by DESeq
whole_colombia_deseq <- phyloseq_to_deseq2(whole_colombia_plus1, ~fiber_adequate)

# run DESeq analysis (note: this uses "adequate" fiber intake as a reference)
DESEQ_whole_colombia <- DESeq(whole_colombia_deseq)

# relevel the dataset, setting the reference group to be the "inadequate" fiber intake group
DESEQ_whole_colombia$fiber_adequate <- relevel(DESEQ_whole_colombia$fiber_adequate, ref = "inadequate")

# re-run DESeq analysis on the releveled data
DESEQ_whole_colombia <- DESeq(DESEQ_whole_colombia)

# obtain a table of DESeq results
whole_res <- results(DESEQ_whole_colombia, tidy=TRUE)
View(whole_res)

# re-format data in preparation of generating volcano plots with labels for significantly differentially abundant genera
taxfp <- "taxonomy.tsv"
tax <- read_delim(taxfp, delim="\t")

# convert taxon strings to a table with separate taxa rank columns
tax_mat <- tax %>%
  separate(col=Taxon, sep="; "
           , into = c("Domain","Phylum","Class","Order","Family","Genus","Species")) %>%
  as.matrix() # Saving as a matrix
# save everything except feature IDs 
tax_mat <- tax_mat[,-1]
# make sampleids the rownames
rownames(tax_mat) <- tax$`Feature ID`

# add a new column to the tax_mat dataframe that includes the ASVs
tax_mat <- tax_mat %>% as.data.frame() %>% mutate(rowname = rownames(.))

# join the table of results from DESeq with the tax_mat to identify the ASVs that are differentially abundant
whole_res_join <- left_join(whole_res, tax_mat)
whole_res_join <- whole_res_join %>% mutate(Genus_plot = str_replace(Genus, "g__", ""))
whole_res_join <- whole_res_join %>% mutate(significant = padj < 0.01 & abs(log2FoldChange) > 2,
                                  logpadj = -log10(padj))

# plot the volcano plot representing differentially abundant genera in adequate vs inadequate fiber groups in whole cohort (Fig 2A)
whole_DESeq_volcano <- ggplot(whole_res_join, aes(x = log2FoldChange, y = logpadj)) +
  geom_point(aes(col=significant)) +
  scale_color_manual(name = "Significant", 
                     values = c("salmon", "grey50"), 
                     breaks = c("TRUE", "FALSE")) +
  theme(axis.title = element_text(face = "bold")) +
  geom_text_repel(aes(label=ifelse(padj<0.0000001, as.character(Genus_plot), '')), size = 3, max.overlaps = 15) +
  labs(y = "-log10(padj)") +
  theme(legend.position = "top")

ggsave("whole_DESeq_volcano.png", plot = whole_DESeq_volcano, width = 5, height = 5)


# DESeq analysis on the older female cohort

# first, filter out values of 0 fiber groups for DESeq 
# since we get a zeros error with unprocessed data, we need to add a '1' count to all reads

OF_colombia_plus1 <- transform_sample_counts(colombia_OF_final, function(x) x+1)

# convert the phyloseq file to a file format readable by DESeq
OF_colombia_deseq <- phyloseq_to_deseq2(OF_colombia_plus1, ~fiber_adequate)

# run DESeq analysis (note: this uses "adequate" fiber intake as a reference)
DESEQ_OF_colombia <- DESeq(OF_colombia_deseq)

# relevel the dataset, setting the reference group to be the "inadequate" fiber intake group
DESEQ_OF_colombia$fiber_adequate <- relevel(DESEQ_OF_colombia$fiber_adequate, ref = "inadequate")

# re-run DESeq analysis on the releveled data
DESEQ_OF_colombia <- DESeq(DESEQ_OF_colombia)

# obtain a table of DESeq results
OF_res <- results(DESEQ_OF_colombia, tidy=TRUE)
View(OF_res)

# join the table of results from older female DESeq with the tax_mat to identify the ASVs that are differentially abundant
OF_res_join <- left_join(OF_res, tax_mat)
OF_res_join <- OF_res_join %>% mutate(Genus_plot = str_replace(Genus, "g__", ""))
OF_res_join <- OF_res_join %>% mutate(significant = padj < 0.01 & abs(log2FoldChange) > 2,
                                  logpadj = -log10(padj))

# plot the volcano plot representing differentially abundant genera in adequate vs inadequate fiber groups in older female cohort (Fig 2B)
OF_DESeq_volcano <- ggplot(OF_res_join, aes(x = log2FoldChange, y = logpadj)) +
  geom_point(aes(col=significant)) +
  scale_color_manual(name = "Significant", 
                     values = c("salmon", "grey50"), 
                     breaks = c("TRUE", "FALSE")) +
  theme(axis.title = element_text(face = "bold")) +
  geom_text_repel(aes(label=ifelse(padj<0.0001, as.character(Genus_plot), '')), size = 3, max.overlaps = 10) +
  labs(y = "-log10(padj)") +
  theme(legend.position = "top")

ggsave("OF_DESeq_volcano.png", plot = OF_DESeq_volcano, width = 5, height = 5)

# we were then interested in looking at microbes that were potentially upregulated/downregulated in both cohorts with fiber intake

# first, create a table of significantly differentially abundant ASVs for whole cohort
whole_sigASVs <- whole_res %>% 
  filter(padj<0.01 & abs(log2FoldChange)>2) %>%
  dplyr::rename(ASV=row)

view(whole_sigASVs)

# retrieve only asv names
whole_sigASVs_vec <- whole_sigASVs %>%
  pull(ASV)

# prune the phyloseq file so that only those ASVs that are significantly differentially abundant remain
whole_colombia_DESeq_sig <- prune_taxa(whole_sigASVs_vec, whole_colombia_final)

# rearrange the data frame so that we can plot it in a bar plot 
whole_sigASVs <- tax_table(whole_colombia_DESeq_sig) %>% as.data.frame() %>%
  rownames_to_column(var="ASV") %>%
  right_join(whole_sigASVs) %>%
  mutate(Genus = str_replace(Genus, "g__", "")) %>%
  mutate(Genus = make.unique(Genus)) %>%
  mutate(Genus = factor(Genus, levels=unique(Genus))) %>%
  mutate(upregulated_fiber = sign(whole_sigASVs$log2FoldChange)) %>%
  arrange(log2FoldChange)


# repeat the above for the older female cohort

# create a table of significantly differentially abundant ASVs for female cohort
OF_sigASVs <- OF_res %>% 
  filter(padj<0.01 & abs(log2FoldChange)>2) %>%
  dplyr::rename(ASV=row)

view(OF_sigASVs)

# retrieve only asv names
OF_sigASVs_vec <- OF_sigASVs %>%
  pull(ASV)

# prune the phyloseq file so that only those ASVs that are significantly differentially abundant remain
OF_colombia_DESeq_sig <- prune_taxa(OF_sigASVs_vec, colombia_OF_final)

# rearrange the data frame so that we can plot it in a bar plot 
OF_sigASVs <- tax_table(OF_colombia_DESeq_sig) %>% as.data.frame() %>%
  rownames_to_column(var="ASV") %>%
  right_join(OF_sigASVs) %>%
  mutate(Genus = str_replace(Genus, "g__", "")) %>%
  mutate(Genus = make.unique(Genus)) %>%
  mutate(Genus = factor(Genus, levels=unique(Genus))) %>%
  mutate(upregulated_fiber = sign(OF_sigASVs$log2FoldChange)) %>%
  arrange(log2FoldChange)

# add column to the whole_sig_ASVs table with "TRUE" for ASVs present (significantlly differentially abundant) in both whole cohort and female cohort
whole_sigASVs <- whole_sigASVs %>% 
  mutate(present_in_both = ASV %in% OF_sigASVs$ASV) %>%
  arrange(log2FoldChange)

# rearrange the data frame so that genera are ordered by their log2FoldChange values
whole_sigASVs_ordered <- whole_sigASVs %>%
  mutate(direction = if_else(log2FoldChange >= 0, "upregulated", "downregulated")) %>%
  arrange(desc(direction), log2FoldChange)

# add column to the OF sigASVs table with "TRUE" for ASVs present (significantlly differentially abundant) in both whole cohort and female cohort
OF_sigASVs <- OF_sigASVs %>%
  mutate(present_in_both = ASV %in% whole_sigASVs$ASV) %>%
  arrange(log2FoldChange)

# rearrange the data frame so that genera are ordered by their log2FoldChange values
OF_sigASVs_ordered <- OF_sigASVs %>%
  mutate(direction = if_else(log2FoldChange >= 0, "upregulated", "downregulated")) %>%
  arrange(desc(direction), log2FoldChange)

# visualize the significant differentially abundant genera using bar plots (whole cohort, Fig 2C)

whole_DESeq_bar <- ggplot(whole_sigASVs_ordered, aes(x = reorder(Genus, log2FoldChange), y = log2FoldChange, fill = present_in_both)) +
  geom_bar(stat = "identity") +
  geom_errorbar(aes(ymin = log2FoldChange - lfcSE, ymax = log2FoldChange + lfcSE)) +
  theme(axis.text.x = element_text(angle = 60, hjust = 1),
        axis.title = element_text(face = "bold")) +
  xlab("Genus") +
  scale_fill_manual(name = "Differentially abundant in both whole cohort and females",
                    values = c("grey50", "#91cf60"),
                    limits = c("FALSE", "TRUE")) +
  theme(legend.position = "top")

ggsave("whole_DESeq_bar.png", plot = whole_DESeq_bar, width = 13, limitsize = FALSE)

# visualize the significant differentially abundant genera using bar plots (older female cohort, Fig 2D)

OF_DESeq_bar <- ggplot(OF_sigASVs_ordered, aes(x = reorder(Genus, log2FoldChange), y = log2FoldChange, fill = present_in_both)) +
  geom_bar(stat = "identity") +
  geom_errorbar(aes(ymin = log2FoldChange - lfcSE, ymax = log2FoldChange + lfcSE)) +
  theme(axis.text.x = element_text(angle = 60, hjust = 1),
        axis.title = element_text(face = "bold")) +
  xlab("Genus") +
  scale_fill_manual(name = "Differentially abundant in both whole cohort and females",
                    values = c("grey50", "#91cf60"),
                    limits = c("FALSE", "TRUE")) +
  theme(legend.position = "top")

ggsave("OF_DESeq_bar.png", plot = OF_DESeq_bar, width = 10, limitsize = FALSE)


############################# "Core" microbiome analysis #############################
# load required packages
library(ggVennDiagram)
library(microbiome)

# load data

load("whole_colombia_rare_22513_depth.RData")
load("colombia_OF_rare_9438_depth.RData")

# convert sample counts to relative abundance
whole_RA <- transform_sample_counts(whole_colombia_rare_22513_depth, fun=function(x) x/sum(x))
OF_RA <- transform_sample_counts(colombia_OF_rare_9438_depth, fun=function(x) x/sum(x))

# identify fiber adequate and inadequate groups 
whole_cohort_adequate <- subset_samples(whole_RA, fiber_category == "adequate")
whole_cohort_inadequate <- subset_samples(whole_RA, fiber_category != "adequate")

OF_cohort_adequate <- subset_samples(OF_RA, fiber_category == "adequate")
OF_cohort_inadequate <- subset_samples(OF_RA, fiber_category != "adequate")

# determine which ASVs are found in more than 10% of samples 
whole_adequate_ASVs <- core_members(whole_cohort_adequate, detection = 0.01, prevalence = 0.10)
whole_inadequate_ASVs <- core_members(whole_cohort_inadequate, detection = 0.01, prevalence = 0.10)

OF_adequate_ASVs <- core_members(OF_cohort_adequate, detection = 0.01, prevalence = 0.10)
OF_inadequate_ASVs <- core_members(OF_cohort_inadequate, detection = 0.01, prevalence = 0.10)

# determine which ASVs these are

tax_table(prune_taxa(whole_adequate_ASVs, whole_colombia_rare_22513_depth))
tax_table(prune_taxa(whole_inadequate_ASVs, whole_colombia_rare_22513_depth))
tax_table(prune_taxa(OF_adequate_ASVs, colombia_OF_rare_9438_depth))
tax_table(prune_taxa(OF_inadequate_ASVs, colombia_OF_rare_9438_depth))


# visualize these groups in a venn diagram (Fig 3)
core_venn <- ggVennDiagram(x=list("Total Cohort Adequate" = whole_adequate_ASVs, 
                                  "Total Cohort Inadequate" = whole_inadequate_ASVs,
                                  "Older Female Cohort Adequate" = OF_adequate_ASVs, 
                                  "Older Female Cohort Inadequate" = OF_inadequate_ASVs)
                      , filename = "Core_microbiome.png", output=TRUE) +
  labs(fill="Count") 

core_venn + scale_x_continuous(expand = expansion(mult = 0.12)) + 
  scale_fill_distiller(palette = "RdBu")

ggsave("core_microbiome_analysis.png", plot = core_venn, height = 9, width = 13)



############################# Indicator Species analysis #############################

# load require packages
library(indicspecies)


# identify indicator species associated with fiber intake in whole cohort

# glom to Genus and convert sample counts to relative abundance
whole_colombia_genus <- tax_glom(whole_colombia_final, "Genus", NArm = FALSE)
whole_colombia_genus_RA <- transform_sample_counts(whole_colombia_genus, fun=function(x) x/sum(x))

# indicator species analysis
whole_isa_colombia <- multipatt(t(otu_table(whole_colombia_genus_RA)), 
                                cluster = sample_data(whole_colombia_genus_RA)$fiber_adequate)
summary(whole_isa_colombia)

# pull out taxonomic information so that we can identify what the indicator ASVs are
whole_taxtable <- tax_table(whole_colombia_final) %>% as.data.frame() %>% rownames_to_column(var="ASV")

whole_indic_species_fiber <- whole_isa_colombia$sign %>%
  rownames_to_column(var="ASV") %>%
  left_join(whole_taxtable) %>%
  filter(p.value<0.05)

write.table(whole_indic_species_fiber, file = "whole_indic_species_fiber.tsv")


# identify indicator species associated with fiber intake in older female cohort

# glom to Genus and convert sample counts to relative abundance
OF_colombia_genus <- tax_glom(colombia_OF_final, "Genus", NArm = FALSE)
OF_colombia_genus_RA <- transform_sample_counts(OF_colombia_genus, fun=function(x) x/sum(x))

# indicator species analysis
OF_isa_colombia <- multipatt(t(otu_table(OF_colombia_genus_RA)), 
                                cluster = sample_data(OF_colombia_genus_RA)$fiber_adequate)
summary(OF_isa_colombia)

# pull out taxonomic information so that we can identify what the indicator ASVs are
OF_taxtable <- tax_table(colombia_OF_final) %>% as.data.frame() %>% rownames_to_column(var="ASV")

OF_indic_species_fiber <- OF_isa_colombia$sign %>%
  rownames_to_column(var="ASV") %>%
  left_join(OF_taxtable) %>%
  filter(p.value<0.05)

write.table(OF_indic_species_fiber, file = "OF_indic_species_fiber.tsv")

# combine ISA tables for Table 1 in manuscript
